.. warning::

   This documentation applies **only** to **MoinMoin version 2** (also known as Moin2,
   Moin 2.0, MoinMoin2, etc.), except where explicitly noted otherwise.
   Moin2 is very different from Moin 1.x, so documentation from one version will not
   apply to the other.

Introducing MoinMoin
====================

.. toctree::
   :maxdepth: 2

   intro/general
   intro/features
   intro/license

Using MoinMoin
==============

.. toctree::
   :maxdepth: 2

   user/accounts
   user/markups
   user/templates_metadata
   user/search
   user/upload
   user/namespaces
   user/subscriptions

Administering MoinMoin
=======================

.. toctree::
   :maxdepth: 2

   admin/requirements
   admin/install
   admin/serve
   admin/configure
   admin/changes
   admin/upgrade
   admin/backup
   admin/index
   admin/password-reset
   admin/maintenance
   man/moin

Getting Support for and Contributing to MoinMoin
================================================

.. toctree::
   :maxdepth: 2

   devel/support
   devel/translate

Developing MoinMoin
=====================

.. toctree::
   :maxdepth: 2

   devel/development

Auto-generated API Docs
=========================

.. toctree::
   :maxdepth: 4

   devel/api/moin


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`
